pub enum RECEIVE2R {
DISABLED,
ENABLED,
}Expand description
Possible values of the field RECEIVE2
Variants
Implementations
Sourceimpl RECEIVE2R
impl RECEIVE2R
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)
Sourcepub fn is_disabled(&self) -> bool
pub fn is_disabled(&self) -> bool
Checks if the value of the field is DISABLED
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Checks if the value of the field is ENABLED