RegisterBlock

Struct RegisterBlock 

pub struct RegisterBlock {
    pub tasks_push_keyslot: TASKS_PUSH_KEYSLOT,
    pub events_keyslot_pushed: EVENTS_KEYSLOT_PUSHED,
    pub events_keyslot_revoked: EVENTS_KEYSLOT_REVOKED,
    pub events_keyslot_error: EVENTS_KEYSLOT_ERROR,
    pub inten: INTEN,
    pub intenset: INTENSET,
    pub intenclr: INTENCLR,
    pub intpend: INTPEND,
    pub status: STATUS,
    pub selectkeyslot: SELECTKEYSLOT,
    /* private fields */
}
Register block

Fields

tasks_push_keyslot: TASKS_PUSH_KEYSLOT

0x00 - Push a key slot over secure APB

events_keyslot_pushed: EVENTS_KEYSLOT_PUSHED

0x100 - Key successfully pushed over secure APB

events_keyslot_revoked: EVENTS_KEYSLOT_REVOKED

0x104 - Key has been revoked and cannot be tasked for selection

events_keyslot_error: EVENTS_KEYSLOT_ERROR

0x108 - No key slot selected, no destination address defined, or error during push operation

inten: INTEN

0x300 - Enable or disable interrupt

intenset: INTENSET

0x304 - Enable interrupt

intenclr: INTENCLR

0x308 - Disable interrupt

intpend: INTPEND

0x30c - Pending interrupts

status: STATUS

0x40c - Status bits for KMU operation

selectkeyslot: SELECTKEYSLOT

0x500 - Select key slot ID to be read over AHB or pushed over secure APB when TASKS_PUSH_KEYSLOT is started