#[repr(C)]pub struct EXTDOMAIN {
pub perm: PERM,
}Expand description
Register block
Fields
perm: PERM0x00 - Description cluster: Access for bus access generated from the external domain n List capabilities of the external domain n