pub enum FRAMINGR {
NOTPRESENT,
PRESENT,
}Expand description
Possible values of the field FRAMING
Variants
Implementations
Sourceimpl FRAMINGR
impl FRAMINGR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)
Sourcepub fn is_not_present(&self) -> bool
pub fn is_not_present(&self) -> bool
Checks if the value of the field is NOTPRESENT
Sourcepub fn is_present(&self) -> bool
pub fn is_present(&self) -> bool
Checks if the value of the field is PRESENT