pub struct RegisterBlock {
pub tasks_push_keyslot: TASKS_PUSH_KEYSLOT,
pub events_keyslot_pushed: EVENTS_KEYSLOT_PUSHED,
pub events_keyslot_revoked: EVENTS_KEYSLOT_REVOKED,
pub events_keyslot_error: EVENTS_KEYSLOT_ERROR,
pub inten: INTEN,
pub intenset: INTENSET,
pub intenclr: INTENCLR,
pub intpend: INTPEND,
pub status: STATUS,
pub selectkeyslot: SELECTKEYSLOT,
/* private fields */
}Expand description
Register block
Fields
tasks_push_keyslot: TASKS_PUSH_KEYSLOT0x00 - Push a key slot over secure APB
events_keyslot_pushed: EVENTS_KEYSLOT_PUSHED0x100 - Key successfully pushed over secure APB
events_keyslot_revoked: EVENTS_KEYSLOT_REVOKED0x104 - Key has been revoked and cannot be tasked for selection
events_keyslot_error: EVENTS_KEYSLOT_ERROR0x108 - No key slot selected, no destination address defined, or error during push operation
inten: INTEN0x300 - Enable or disable interrupt
intenset: INTENSET0x304 - Enable interrupt
intenclr: INTENCLR0x308 - Disable interrupt
intpend: INTPEND0x30c - Pending interrupts
status: STATUS0x40c - Status bits for KMU operation
selectkeyslot: SELECTKEYSLOT0x500 - Select key slot ID to be read over AHB or pushed over secure APB when TASKS_PUSH_KEYSLOT is started