pub struct RegisterBlock {Show 18 fields
pub events_ramaccerr: EVENTS_RAMACCERR,
pub events_flashaccerr: EVENTS_FLASHACCERR,
pub events_periphaccerr: EVENTS_PERIPHACCERR,
pub publish_ramaccerr: PUBLISH_RAMACCERR,
pub publish_flashaccerr: PUBLISH_FLASHACCERR,
pub publish_periphaccerr: PUBLISH_PERIPHACCERR,
pub inten: INTEN,
pub intenset: INTENSET,
pub intenclr: INTENCLR,
pub cap: CAP,
pub extdomain: [EXTDOMAIN; 1],
pub dppi: [DPPI; 1],
pub gpioport: [GPIOPORT; 1],
pub flashnsc: [FLASHNSC; 2],
pub ramnsc: [RAMNSC; 2],
pub flashregion: [FLASHREGION; 32],
pub ramregion: [RAMREGION; 32],
pub periphid: [PERIPHID; 67],
/* private fields */
}Expand description
Register block
Fields
events_ramaccerr: EVENTS_RAMACCERR0x100 - A security violation has been detected for the RAM memory space
events_flashaccerr: EVENTS_FLASHACCERR0x104 - A security violation has been detected for the flash memory space
events_periphaccerr: EVENTS_PERIPHACCERR0x108 - A security violation has been detected on one or several peripherals
publish_ramaccerr: PUBLISH_RAMACCERR0x180 - Publish configuration for event RAMACCERR
publish_flashaccerr: PUBLISH_FLASHACCERR0x184 - Publish configuration for event FLASHACCERR
publish_periphaccerr: PUBLISH_PERIPHACCERR0x188 - Publish configuration for event PERIPHACCERR
inten: INTEN0x300 - Enable or disable interrupt
intenset: INTENSET0x304 - Enable interrupt
intenclr: INTENCLR0x308 - Disable interrupt
cap: CAP0x400 - Show implemented features for the current device
extdomain: [EXTDOMAIN; 1]0x440 - Unspecified
dppi: [DPPI; 1]0x480 - Unspecified
gpioport: [GPIOPORT; 1]0x4c0 - Unspecified
flashnsc: [FLASHNSC; 2]0x500 - Unspecified
ramnsc: [RAMNSC; 2]0x540 - Unspecified
flashregion: [FLASHREGION; 32]0x600 - Unspecified
ramregion: [RAMREGION; 32]0x700 - Unspecified
periphid: [PERIPHID; 67]0x800 - Unspecified